@@ -121,16 +121,16 @@ def pwdhash(domain, password):
 
 def _check_iterations_and_salt(iterations, salt):
     if salt is None:
-        raise Exception(
-            'Please define {0!r} environment variable, or specify --salt.'.format(PWDHASH2_SALT_ENV))
+        sys.exit('Please define {0!r} environment variable, or specify --salt.'.format(PWDHASH2_SALT_ENV))
     if iterations is None:
-        raise Exception(
-            'Please define {0!r} environment variable, or specify --iterations.'.format(PWDHASH2_ITERATIONS_ENV))
+        sys.exit('Please define {0!r} environment variable, or specify --iterations.'.format(PWDHASH2_ITERATIONS_ENV))
 
 def _args_parser(description):
     parser = argparse.ArgumentParser(description=description)
     parser.add_argument('-s', '--stdin', action='store_true',
                         help='Get password from stdin instead of prompt. Default is prompt')
+    parser.add_argument('-t', '--twice', action='store_true',
+                        help='Ask password twice, and check both are the same. Default is once')
     parser.add_argument('-c', '--copy', action='store_true',
                         help='Copy hash to clipboard instead of displaying it. Default is display')
     parser.add_argument('-n', action='store_true',
@@ -157,6 +157,10 @@ def _process(parser, cli_args, version=None):
         password = sys.stdin.readline().strip()
     else:
         password = getpass.getpass()
+        if args.twice:
+            password2 = getpass.getpass('Enter password again:')
+            if password != password2:
+                sys.exit('ERROR: Passwords did not match.')
 
     if version == 1:
         result = pwdhash(domain, password)
